resource "oci_core_instance" "guide_vm" {
  agent_config {
    is_management_disabled = "false"
    is_monitoring_disabled = "false"
    plugins_config {
      desired_state = "DISABLED"
      name          = "Vulnerability Scanning"
    }
    plugins_config {
      desired_state = "DISABLED"
      name          = "Oracle Java Management Service"
    }
    plugins_config {
      desired_state = "ENABLED"
      name          = "OS Management Service Agent"
    }
    plugins_config {
      desired_state = "DISABLED"
      name          = "Management Agent"
    }
    plugins_config {
      desired_state = "ENABLED"
      name          = "Compute Instance Run Command"
    }
    plugins_config {
      desired_state = "ENABLED"
      name          = "Compute Instance Monitoring"
    }
    plugins_config {
      desired_state = "DISABLED"
      name          = "Block Volume Management"
    }
    plugins_config {
      desired_state = "DISABLED"
      name          = "Bastion"
    }
  }
  availability_config {
    is_live_migration_preferred = "true"
    recovery_action             = "RESTORE_INSTANCE"
  }
  availability_domain = data.oci_identity_availability_domain.ad1.name
  compartment_id      = local.compartment_ocid
  create_vnic_details {
    assign_ipv6ip             = "false"
    assign_private_dns_record = "true"
    assign_public_ip          = "true"
    subnet_id                 = oci_core_subnet.public_subnet.id
  }
  display_name = "GDK_MySQL_guide_VM"
  instance_options {
    are_legacy_imds_endpoints_disabled = "false"
  }
  metadata = {
    "ssh_authorized_keys" = "${var.ssh_public_key}"
    "user_data"           = "${base64encode(templatefile("${path.module}/gdk_mysql_compute_instance_config.tftpl", {}))}"
  }
  shape = "VM.Standard.E4.Flex"
  shape_config {
    baseline_ocpu_utilization = "BASELINE_1_1"
    memory_in_gbs             = "64"
    ocpus                     = "4"
  }
  source_details {
    source_id   = "ocid1.image.oc1.phx.aaaaaaaavitkmkuakgkiv5jbu365dd6hqr6do6lrqshhvgut5564ndcoeyaa"
    source_type = "image"
  }
}
